#### Install cubiq/ComfyUI_IPAdapter_plus

```shell
cd ComfyUI/custom_nodes
git clone https://github.com/cubiq/ComfyUI_IPAdapter_plus.git
# Date:   Thu Jul 18 15:12:49 2024 +0200
git reset --hard  78ac59c61c8caf33e3419d2c8f70838b2da0fb04
```
#### cubiq/PuLID_ComfyUI

```shell
cd ComfyUI/custom_nodes
git clone https://github.com/cubiq/PuLID_ComfyUI.git
# Date:   Sun May 26 19:23:51 2024 +0200
git reset --hard  80d157ace9e4d2db8c963e770ed99d492d0f4569
```

#### Install cubiq/ComfyUI_InstantID

```shell
cd ComfyUI/custom_nodes
git clone https://github.com/cubiq/ComfyUI_InstantID.git
# Date:   Thu Jul 11 19:26:22 2024 +0200
git reset --hard  6d95aa6758e58dab550725e59dcefbd426c160c7
```

#### Install ComfyUI-AnimateDiff-Evolved

```shell
cd ComfyUI/custom_nodes
git clone https://github.com/Kosinkadink/ComfyUI-AnimateDiff-Evolved.git
git reset --hard  1b660e535381a4b4e4028aad38b7ae21c81b861c
```
